@@ -1276,6 +1276,10 @@ class DataReport(RepositoryItem):
     def author(self):
         return self._data.get('author')
 
+    @property
+    def front_page(self):
+        return self._data['front_page']
+
 
 class ImageHealth(object):
 
@@ -1332,6 +1336,10 @@ class ImageHealth(object):
         since = until - datetime.timedelta(days=last_n_days)
         return self.get_test_runs(
         ).select_related(
+            'denormalization',
+            'bundle',
+            'bundle__bundle_stream',
+            'test',
         ).filter(
             analyzer_assigned_date__range=(since, until)
         ).order_by('-analyzer_assigned_date')
